# image_processing

Description. 
The package image_processing is used to:
	Processing:
		- Histogram matching 
		- Structural similarity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram 

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image-processing

```bash
pip install image_processing
```

## Author
Vinicius, slightly modified version from Karina Kato

## License
[MIT](https://choosealicense.com/licenses/mit/)